You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@couchdb.apache.org by rn...@apache.org on 2013/12/19 00:04:48 UTC

[2/3] Build with rebar

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/share/doc/build/Makefile.am
----------------------------------------------------------------------
diff --git a/share/doc/build/Makefile.am b/share/doc/build/Makefile.am
deleted file mode 100644
index 3db9689..0000000
--- a/share/doc/build/Makefile.am
+++ /dev/null
@@ -1,354 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-MAKE_SAFE = $(MAKE)
-
-SPHINXOPTS = \
-    -n -c $(srcdir)/../src \
-    -A local=1 \
-    $(srcdir)/../src
-
-info_file_dist = texinfo/CouchDB.info
-
-info_file_inst = CouchDB
-
-if BUILD_INFO
-info_file_build = $(info_file_dist)
-else
-info_file_build =
-endif
-
-pdf_file_dist = latex/CouchDB.pdf.gz
-
-pdf_file_inst = CouchDB.pdf.gz
-
-if BUILD_PDF
-pdf_file_build = $(pdf_file_dist)
-else
-pdf_file_build =
-endif
-
-# Please keep lists of rst and related generated files sorted
-
-html_files = \
-    html/_images/futon-createdb.png \
-    html/_images/futon-editdoc.png \
-    html/_images/futon-editeddoc.png \
-    html/_images/futon-overview.png \
-    html/_images/futon-replform.png \
-    html/_sources/api/authn.txt \
-    html/_sources/api/configuration.txt \
-    html/_sources/api/database.txt \
-    html/_sources/api/dbmaint.txt \
-    html/_sources/api/design.txt \
-    html/_sources/api/documents.txt \
-    html/_sources/api/local.txt \
-    html/_sources/api/misc.txt \
-    html/_sources/api/reference.txt \
-    html/_sources/api-basics.txt \
-    html/_sources/changelog.txt \
-    html/_sources/changes.txt \
-    html/_sources/commonjs.txt \
-    html/_sources/cors.txt \
-    html/_sources/config_reference.txt \
-    html/_sources/configuring.txt \
-    html/_sources/ddocs.txt \
-    html/_sources/errors.txt \
-    html/_sources/http-proxying.txt \
-    html/_sources/index.txt \
-    html/_sources/intro.txt \
-    html/_sources/json-structure.txt \
-    html/_sources/os-daemons.txt \
-    html/_sources/pretty_urls.txt \
-    html/_sources/query-servers.txt \
-    html/_sources/range.txt \
-    html/_sources/release.txt \
-    html/_sources/replication.txt \
-    html/_sources/ssl.txt \
-    html/_static/ajax-loader.gif \
-    html/_static/basic.css \
-    html/_static/comment-bright.png \
-    html/_static/comment-close.png \
-    html/_static/comment.png \
-    html/_static/default.css \
-    html/_static/doctools.js \
-    html/_static/down-pressed.png \
-    html/_static/down.png \
-    html/_static/favicon.ico \
-    html/_static/file.png \
-    html/_static/jquery.js \
-    html/_static/logo.png \
-    html/_static/minus.png \
-    html/_static/plus.png \
-    html/_static/pygments.css \
-    html/_static/rtd.css \
-    html/_static/searchtools.js \
-    html/_static/sidebar.js \
-    html/_static/underscore.js \
-    html/_static/up-pressed.png \
-    html/_static/up.png \
-    html/_static/websupport.js \
-    html/api/authn.html \
-    html/api/configuration.html \
-    html/api/database.html \
-    html/api/dbmaint.html \
-    html/api/design.html \
-    html/api/documents.html \
-    html/api/local.html \
-    html/api/misc.html \
-    html/api/reference.html \
-    html/api-basics.html \
-    html/changelog.html \
-    html/changes.html \
-    html/commonjs.html \
-    html/cors.html \
-    html/config_reference.html \
-    html/configuring.html \
-    html/ddocs.html \
-    html/errors.html \
-    html/http-proxying.html \
-    html/index.html \
-    html/intro.html \
-    html/json-structure.html \
-    html/os-daemons.html \
-    html/pretty_urls.html \
-    html/query-servers.html \
-    html/range.html \
-    html/release.html \
-    html/replication.html \
-    html/ssl.html \
-    html/objects.inv \
-    html/genindex.html \
-    html/search.html \
-    html/searchindex.js
-
-if BUILD_HTML
-html_files_build = $(html_files)
-else
-html_files_build =
-endif
-
-image_files = \
-    ../images/epub-icon.png \
-    ../images/favicon.ico \
-    ../images/futon-createdb.png \
-    ../images/futon-editdoc.png \
-    ../images/futon-editeddoc.png \
-    ../images/futon-overview.png \
-    ../images/futon-replform.png \
-    ../images/logo.png
-
-src_files = \
-    ../src/api/authn.rst \
-    ../src/api/configuration.rst \
-    ../src/api/database.rst \
-    ../src/api/dbmaint.rst \
-    ../src/api/design.rst \
-    ../src/api/documents.rst \
-    ../src/api/local.rst \
-    ../src/api/misc.rst \
-    ../src/api/reference.rst \
-    ../src/api-basics.rst \
-    ../src/changelog.rst \
-    ../src/changes.rst \
-    ../src/commonjs.rst \
-    ../src/cors.rst \
-    ../src/config_reference.rst \
-    ../src/configuring.rst \
-    ../src/ddocs.rst \
-    ../src/errors.rst \
-    ../src/http-proxying.rst \
-    ../src/index.rst \
-    ../src/intro.rst \
-    ../src/json-structure.rst \
-    ../src/os-daemons.rst \
-    ../src/pretty_urls.rst \
-    ../src/query-servers.rst \
-    ../src/range.rst \
-    ../src/release.rst \
-    ../src/replication.rst \
-    ../src/ssl.rst \
-    ../src/conf.py
-
-src_files_html = \
-    ../static/rtd.css \
-    ../templates/help.html \
-    ../templates/searchbox.html \
-    ../templates/utilities.html
-
-EXTRA_DIST = \
-    $(image_files) \
-    $(src_files) \
-    $(src_files_html) \
-    $(info_file_build) \
-    $(pdf_file_build) \
-    $(html_files_build)
-
-BUILT_SOURCES = \
-    $(info_file_build) \
-    $(pdf_file_build) \
-    $(html_files_build)
-
-$(pdf_file_dist): pdf
-
-$(html_files): html
-
-$(info_file_dist): info.stamp
-	@if test -f $@; then :; else \
-	    rm -f info.stamp; \
-	    $(MAKE_SAFE) $(AM_MAKEFLAGS) info.stamp; \
-	fi
-
-info.stamp: $(image_files) $(src_files)
-	trap "rm -rf info.lock info.stamp" 1 2 13 15; \
-	if mkdir info.lock 2>/dev/null; then \
-	    rm -f info.tmp; \
-	    touch info.tmp; \
-	    $(top_srcdir)/build-aux/sphinx-build \
-	        -b texinfo $(SPHINXOPTS) $(builddir)/texinfo; \
-	    $(MAKE_SAFE) -C texinfo info; \
-	    $(top_srcdir)/build-aux/sphinx-touch $(info_file_dist); \
-	    mv -f info.tmp $@; \
-	    rmdir info.lock; \
-	else \
-	    while test -d info.lock; do \
-	        sleep 1; \
-	    done; \
-	    test -f info.stamp; \
-	fi
-
-$(pdf_file_dist): pdf.stamp
-	@if test -f $@; then :; else \
-	    rm -f pdf.stamp; \
-	    $(MAKE_SAFE) $(AM_MAKEFLAGS) pdf.stamp; \
-	fi
-
-pdf.stamp: $(image_files) $(src_files)
-	trap "rm -rf pdf.lock pdf.stamp" 1 2 13 15; \
-	if mkdir pdf.lock 2>/dev/null; then \
-	    rm -f pdf.tmp; \
-	    touch pdf.tmp; \
-	    $(top_srcdir)/build-aux/sphinx-build \
-	        -b latex $(SPHINXOPTS) $(builddir)/latex; \
-	    $(MAKE_SAFE) -C latex all-pdf; \
-	    $(top_srcdir)/build-aux/sphinx-touch latex/CouchDB.pdf; \
-	    gzip -9 < latex/CouchDB.pdf > $(pdf_file_dist); \
-	    mv -f pdf.tmp $@; \
-	    rmdir pdf.lock; \
-	else \
-	    while test -d pdf.lock; do \
-	        sleep 1; \
-	    done; \
-	    test -f pdf.stamp; \
-	fi
-
-$(html_files): html.stamp
-	@if test -f $@; then :; else \
-	    rm -f html.stamp; \
-	    $(MAKE_SAFE) $(AM_MAKEFLAGS) html.stamp; \
-	fi
-
-html.stamp: $(image_files) $(src_files) $(src_files_html)
-	trap "rm -rf html.lock html.stamp" 1 2 13 15; \
-	if mkdir html.lock 2>/dev/null; then \
-	    rm -f html.tmp; \
-	    touch html.tmp; \
-	    $(top_srcdir)/build-aux/sphinx-build \
-	        -b html $(SPHINXOPTS) $(builddir)/html; \
-	    $(top_srcdir)/build-aux/sphinx-touch $(html_files); \
-	    mv -f html.tmp $@; \
-	    rmdir html.lock; \
-	else \
-	    while test -d html.lock; do \
-	        sleep 1; \
-	    done; \
-	    test -f html.stamp; \
-	fi
-
-pdf-local:
-	$(MAKE) $(AM_MAKEFLAGS) pdf.stamp
-
-html-local:
-	$(MAKE) $(AM_MAKEFLAGS) html.stamp
-
-install-data-local:
-	if test -s $(info_file_dist); then \
-	    $(INSTALL) -d $(DESTDIR)$(infodir); \
-	    $(INSTALL_DATA) \
-	        $(info_file_dist) $(DESTDIR)$(infodir)/$(info_file_inst); \
-	    if test -n "`which install-info`"; then \
-	        install-info \
-	            $(DESTDIR)$(infodir)/$(info_file_inst) \
-	            $(DESTDIR)$(infodir)/dir \
-	        || true; \
-	    fi \
-	fi
-	if test -s $(pdf_file_dist); then \
-	    $(INSTALL) -d $(DESTDIR)$(localdocdir); \
-	    $(INSTALL_DATA) \
-	        $(pdf_file_dist) $(DESTDIR)$(localdocdir)/$(pdf_file_inst); \
-	fi
-	for dist_file in $(html_files); do \
-	    if test -s $$dist_file; then \
-	        inst_file=`echo $$dist_file | sed s,^html,docs,`; \
-	        $(INSTALL) -d `dirname $(DESTDIR)$(localdatadir)/www/$$inst_file`; \
-	        $(INSTALL_DATA) \
-	            $$dist_file $(DESTDIR)$(localdatadir)/www/$$inst_file; \
-	    fi \
-	done
-
-uninstall-local:
-	rm -f $(DESTDIR)$(infodir)/$(info_file_inst)
-	if test -d $(DESTDIR)$(infodir); then \
-	    if test -n "`which install-info`"; then\
-	        install-info \
-	            --delete \
-	            $(DESTDIR)$(infodir)/$(info_file_inst) \
-	            $(DESTDIR)$(infodir)/dir \
-	        || true; \
-	    fi \
-	fi
-	rm -f $(DESTDIR)$(localdocdir)/$(pdf_file_inst)
-	for dist_file in $(html_files); do \
-	    if test -s $$dist_file; then \
-	        inst_file=`echo $$dist_file | sed s,^html,docs,`; \
-	        rm -f $(DESTDIR)$(localdatadir)/www/$$inst_file; \
-	    fi \
-	done
-
-DISTCLEANFILES = \
-    info.stamp \
-    pdf.stamp \
-    html.stamp
-
-distclean-local:
-	rm -fr doctrees
-	rm -fr html
-	rm -fr latex
-	rm -fr texinfo
-
-# We handle exit code manually. Please fix if there is a better way.
-distcheck-hook:
-	if test ! -s $(info_file_dist); then \
-	    $(top_srcdir)/build-aux/dist-error $(info_file_dist); \
-	fi
-	if test ! -s $(pdf_file_dist); then \
-	    $(top_srcdir)/build-aux/dist-error $(pdf_file_dist); \
-	fi
-	exit_code=0; \
-	for file in $(html_files); do \
-	    if test ! -s $$file; then \
-	        exit_code=1; \
-	        $(top_srcdir)/build-aux/dist-error $$file || break; \
-	    fi \
-	done; \
-	exit $$exit_code;

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/Makefile.am
----------------------------------------------------------------------
diff --git a/src/Makefile.am b/src/Makefile.am
deleted file mode 100644
index 2b05fbd..0000000
--- a/src/Makefile.am
+++ /dev/null
@@ -1,30 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-SUBDIRS = \
-    snappy \
-    ejson \
-    ibrowse \
-    mochiweb \
-    oauth \
-    config \
-    couch_index \
-    couch_mrview \
-    couch_replicator \
-    couch \
-	twig \
-	rexi \
-	mem3 \
-	fabric \
-	ets_lru \
-	ddoc_cache \
-	chttpd

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/chttpd/.gitignore
----------------------------------------------------------------------
diff --git a/src/chttpd/.gitignore b/src/chttpd/.gitignore
deleted file mode 100644
index ba4df8d..0000000
--- a/src/chttpd/.gitignore
+++ /dev/null
@@ -1 +0,0 @@
-ebin/*
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/chttpd/Makefile.am
----------------------------------------------------------------------
diff --git a/src/chttpd/Makefile.am b/src/chttpd/Makefile.am
deleted file mode 100644
index c785968..0000000
--- a/src/chttpd/Makefile.am
+++ /dev/null
@@ -1,56 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-chttpdebindir = $(localerlanglibdir)/chttpd/ebin
-
-chttpdebin_DATA = $(compiled_files)
-
-source_files = \
-	src/chttpd.app.src \
-	src/chttpd.erl \
-	src/chttpd_app.erl \
-	src/chttpd_config_listener.erl \
-	src/chttpd_db.erl \
-	src/chttpd_external.erl \
-	src/chttpd_misc.erl \
-	src/chttpd_rewrite.erl \
-	src/chttpd_show.erl \
-	src/chttpd_sup.erl \
-	src/chttpd_view.erl
-
-compiled_files = \
-	ebin/chttpd.app \
-	ebin/chttpd.beam \
-	ebin/chttpd_app.beam \
-	ebin/chttpd_config_listener.beam \
-	ebin/chttpd_db.beam \
-	ebin/chttpd_external.beam \
-	ebin/chttpd_misc.beam \
-	ebin/chttpd_rewrite.beam \
-	ebin/chttpd_show.beam \
-	ebin/chttpd_sup.beam
-
-# Conflicts in couch_db.hrl prevent us from building these
-# until after we merge the couch application
-#	ebin/chttpd_view.beam
-
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/chttpd/README.md
----------------------------------------------------------------------
diff --git a/src/chttpd/README.md b/src/chttpd/README.md
deleted file mode 100644
index 784bedd..0000000
--- a/src/chttpd/README.md
+++ /dev/null
@@ -1,16 +0,0 @@
-## chttpd
-
-chttpd is a cluster-aware http layer for [CouchDB][1].  It is used in [BigCouch][2] as the http front-end.
-
-### License
-[Apache 2.0][3]
-
-### Contact
- * [http://cloudant.com][4]
- * [info@cloudant.com][5]
-
-[1]: http://couchdb.apache.org
-[2]: http://github.com/cloudant/bigcouch
-[3]: http://www.apache.org/licenses/LICENSE-2.0.html
-[4]: http://cloudant.com
-[5]: mailto:info@cloudant.com

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/chttpd/src/chttpd.app.src
----------------------------------------------------------------------
diff --git a/src/chttpd/src/chttpd.app.src b/src/chttpd/src/chttpd.app.src
index d841f6c..9ab91c8 100644
--- a/src/chttpd/src/chttpd.app.src
+++ b/src/chttpd/src/chttpd.app.src
@@ -12,7 +12,7 @@
 
  {application, chttpd, [
     {description, "HTTP interface for CouchDB cluster"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         chttpd,
         chttpd_app,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/chttpd/src/chttpd_view.erl
----------------------------------------------------------------------
diff --git a/src/chttpd/src/chttpd_view.erl b/src/chttpd/src/chttpd_view.erl
index 2c64dda..85b88a3 100644
--- a/src/chttpd/src/chttpd_view.erl
+++ b/src/chttpd/src/chttpd_view.erl
@@ -12,6 +12,7 @@
 
 -module(chttpd_view).
 -include_lib("couch/include/couch_db.hrl").
+-include_lib("couch_mrview/include/couch_mrview.hrl").
 
 -export([handle_view_req/3, handle_temp_view_req/2, get_reduce_type/1,
     parse_view_params/3, view_group_etag/2, view_group_etag/3,
@@ -91,11 +92,11 @@ view_callback({error, Reason}, {_, Resp}) ->
 extract_view_type(_ViewName, [], _IsReduce) ->
     throw({not_found, missing_named_view});
 extract_view_type(ViewName, [View|Rest], IsReduce) ->
-    case lists:member(ViewName, [Name || {Name, _} <- View#view.reduce_funs]) of
+    case lists:member(ViewName, [Name || {Name, _} <- View#mrview.reduce_funs]) of
     true ->
         if IsReduce -> reduce; true -> red_map end;
     false ->
-        case lists:member(ViewName, View#view.map_names) of
+        case lists:member(ViewName, View#mrview.map_names) of
         true -> map;
         false -> extract_view_type(ViewName, Rest, IsReduce)
         end
@@ -153,7 +154,7 @@ parse_view_params(Req, Keys, ViewType) when not is_list(Req) ->
     parse_view_params(QueryParams, Keys, ViewType);
 parse_view_params(QueryParams, Keys, ViewType) ->
     IsMultiGet = (Keys =/= nil),
-    Args = #view_query_args{
+    Args = #mrargs{
         view_type=ViewType,
         multi_get=IsMultiGet,
         keys=Keys
@@ -162,7 +163,7 @@ parse_view_params(QueryParams, Keys, ViewType) ->
         validate_view_query(K, V, Args2)
     end, Args, QueryParams),
 
-    GroupLevel = QueryArgs#view_query_args.group_level,
+    GroupLevel = QueryArgs#mrargs.group_level,
     case {ViewType, GroupLevel, IsMultiGet} of
         {reduce, exact, true} ->
             QueryArgs;
@@ -180,9 +181,9 @@ parse_view_params(QueryParams, Keys, ViewType) ->
 parse_json_view_param({<<"key">>, V}) ->
     [{start_key, V}, {end_key, V}];
 parse_json_view_param({<<"startkey_docid">>, V}) ->
-    [{start_docid, V}];
+    [{start_key_docid, V}];
 parse_json_view_param({<<"endkey_docid">>, V}) ->
-    [{end_docid, V}];
+    [{end_key_docid, V}];
 parse_json_view_param({<<"startkey">>, V}) ->
     [{start_key, V}];
 parse_json_view_param({<<"endkey">>, V}) ->
@@ -224,9 +225,9 @@ parse_view_param("key", Value) ->
     JsonKey = ?JSON_DECODE(Value),
     [{start_key, JsonKey}, {end_key, JsonKey}];
 parse_view_param("startkey_docid", Value) ->
-    [{start_docid, ?l2b(Value)}];
+    [{start_key_docid, ?l2b(Value)}];
 parse_view_param("endkey_docid", Value) ->
-    [{end_docid, ?l2b(Value)}];
+    [{end_key_docid, ?l2b(Value)}];
 parse_view_param("startkey", Value) ->
     [{start_key, ?JSON_DECODE(Value)}];
 parse_view_param("endkey", Value) ->
@@ -273,64 +274,64 @@ parse_view_param(Key, Value) ->
     [{extra, {Key, Value}}].
 
 validate_view_query(start_key, Value, Args) ->
-    case Args#view_query_args.multi_get of
+    case Args#mrargs.multi_get of
         true ->
             Msg = <<"Query parameter `start_key` is "
                     "not compatiible with multi-get">>,
             throw({query_parse_error, Msg});
         _ ->
-            Args#view_query_args{start_key=Value}
+            Args#mrargs{start_key=Value}
     end;
-validate_view_query(start_docid, Value, Args) ->
-    Args#view_query_args{start_docid=Value};
+validate_view_query(start_key_docid, Value, Args) ->
+    Args#mrargs{start_key_docid=Value};
 validate_view_query(end_key, Value, Args) ->
-    case Args#view_query_args.multi_get of
+    case Args#mrargs.multi_get of
         true->
             Msg = <<"Query paramter `end_key` is "
                     "not compatibile with multi-get">>,
             throw({query_parse_error, Msg});
         _ ->
-            Args#view_query_args{end_key=Value}
+            Args#mrargs{end_key=Value}
     end;
-validate_view_query(end_docid, Value, Args) ->
-    Args#view_query_args{end_docid=Value};
+validate_view_query(end_key_docid, Value, Args) ->
+    Args#mrargs{end_key_docid=Value};
 validate_view_query(limit, Value, Args) ->
-    Args#view_query_args{limit=Value};
+    Args#mrargs{limit=Value};
 validate_view_query(list, Value, Args) ->
-    Args#view_query_args{list=Value};
+    Args#mrargs{list=Value};
 validate_view_query(stale, Value, Args) ->
-    Args#view_query_args{stale=Value};
+    Args#mrargs{stale=Value};
 validate_view_query(descending, true, Args) ->
-    case Args#view_query_args.direction of
+    case Args#mrargs.direction of
         rev -> Args; % Already reversed
         fwd ->
-            Args#view_query_args{
+            Args#mrargs{
                 direction = rev,
-                start_docid =
-                    reverse_key_default(Args#view_query_args.start_docid),
-                end_docid =
-                    reverse_key_default(Args#view_query_args.end_docid)
+                start_key_docid =
+                    reverse_key_default(Args#mrargs.start_key_docid),
+                end_key_docid =
+                    reverse_key_default(Args#mrargs.end_key_docid)
             }
     end;
 validate_view_query(descending, false, Args) ->
     Args; % Ignore default condition
 validate_view_query(skip, Value, Args) ->
-    Args#view_query_args{skip=Value};
+    Args#mrargs{skip=Value};
 validate_view_query(group_level, Value, Args) ->
-    case Args#view_query_args.view_type of
+    case Args#mrargs.view_type of
         reduce ->
-            Args#view_query_args{group_level=Value};
+            Args#mrargs{group_level=Value};
         _ ->
             Msg = <<"Invalid URL parameter 'group' or "
                     " 'group_level' for non-reduce view.">>,
             throw({query_parse_error, Msg})
     end;
 validate_view_query(inclusive_end, Value, Args) ->
-    Args#view_query_args{inclusive_end=Value};
+    Args#mrargs{inclusive_end=Value};
 validate_view_query(reduce, false, Args) ->
     Args;
 validate_view_query(reduce, _, Args) ->
-    case Args#view_query_args.view_type of
+    case Args#mrargs.view_type of
         map ->
             Msg = <<"Invalid URL parameter `reduce` for map view.">>,
             throw({query_parse_error, Msg});
@@ -338,29 +339,29 @@ validate_view_query(reduce, _, Args) ->
             Args
     end;
 validate_view_query(include_docs, true, Args) ->
-    case Args#view_query_args.view_type of
+    case Args#mrargs.view_type of
         reduce ->
             Msg = <<"Query paramter `include_docs` "
                     "is invalid for reduce views.">>,
             throw({query_parse_error, Msg});
         _ ->
-            Args#view_query_args{include_docs=true}
+            Args#mrargs{include_docs=true}
     end;
 validate_view_query(include_docs, _Value, Args) ->
     Args;
 validate_view_query(conflicts, true, Args) ->
-    case Args#view_query_args.view_type of
+    case Args#mrargs.view_type of
     reduce ->
         Msg = <<"Query parameter `conflicts` "
                 "is invalid for reduce views.">>,
         throw({query_parse_error, Msg});
     _ ->
-        Args#view_query_args{extra = [conflicts|Args#view_query_args.extra]}
+        Args#mrargs{extra = [conflicts|Args#mrargs.extra]}
     end;
 validate_view_query(conflicts, _Value, Args) ->
     Args;
 validate_view_query(sorted, false, Args) ->
-    Args#view_query_args{sorted=false};
+    Args#mrargs{sorted=false};
 validate_view_query(sorted, _Value, Args) ->
     Args;
 validate_view_query(extra, _Value, Args) ->

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/config/.gitignore
----------------------------------------------------------------------
diff --git a/src/config/.gitignore b/src/config/.gitignore
deleted file mode 100644
index c57e7cf..0000000
--- a/src/config/.gitignore
+++ /dev/null
@@ -1,5 +0,0 @@
-ebin
-deps
-.eunit
-*~
-*.swp

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/config/Makefile.am
----------------------------------------------------------------------
diff --git a/src/config/Makefile.am b/src/config/Makefile.am
deleted file mode 100644
index 86731a2..0000000
--- a/src/config/Makefile.am
+++ /dev/null
@@ -1,44 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-configebindir = $(localerlanglibdir)/config/ebin
-
-configebin_DATA = $(compiled_files)
-
-source_files = \
-	src/config.app.src \
-    src/config.erl \
-	src/config_app.erl \
-	src/config_listener.erl \
-	src/config_sup.erl \
-	src/config_util.erl \
-	src/config_writer.erl
-
-compiled_files = \
-	ebin/config.app \
-    ebin/config.beam \
-	ebin/config_app.beam \
-	ebin/config_listener.beam \
-	ebin/config_sup.beam \
-	ebin/config_util.beam \
-	ebin/config_writer.beam
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/config/src/config.app.src
----------------------------------------------------------------------
diff --git a/src/config/src/config.app.src b/src/config/src/config.app.src
index 9b0f5f0..6eea351 100644
--- a/src/config/src/config.app.src
+++ b/src/config/src/config.app.src
@@ -12,7 +12,7 @@
 
 {application, config, [
     {description, "INI file configuration system for Apache CouchDB"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         config,
         config_app,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch/Makefile.am
----------------------------------------------------------------------
diff --git a/src/couch/Makefile.am b/src/couch/Makefile.am
deleted file mode 100644
index 5f47bcd..0000000
--- a/src/couch/Makefile.am
+++ /dev/null
@@ -1,204 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-SUBDIRS = priv
-
-# devdocdir = $(localdocdir)/developer/couchdb
-couchlibdir = $(localerlanglibdir)/couch-$(version)
-couchincludedir = $(couchlibdir)/include
-couchebindir = $(couchlibdir)/ebin
-
-couchinclude_DATA = include/couch_db.hrl
-couchebin_DATA = $(compiled_files)
-
-# dist_devdoc_DATA = $(doc_base) $(doc_modules)
-
-CLEANFILES = $(compiled_files) $(doc_base)
-
-# CLEANFILES = $(doc_modules) edoc-info
-
-source_files = \
-    src/couch.erl \
-    src/couch_app.erl \
-    src/couch_auth_cache.erl \
-    src/couch_btree.erl \
-    src/couch_changes.erl \
-    src/couch_compaction_daemon.erl \
-    src/couch_compress.erl \
-    src/couch_config.erl \
-    src/couch_config_writer.erl \
-    src/couch_db.erl \
-    src/couch_db_update_notifier.erl \
-    src/couch_db_update_notifier_sup.erl \
-    src/couch_doc.erl \
-    src/couch_drv.erl \
-    src/couch_ejson_compare.erl \
-    src/couch_emsort.erl \
-    src/couch_event_sup.erl \
-    src/couch_external_manager.erl \
-    src/couch_external_server.erl \
-    src/couch_file.erl \
-    src/couch_httpd.erl \
-    src/couch_httpd_db.erl \
-    src/couch_httpd_auth.erl \
-    src/couch_httpd_cors.erl \
-    src/couch_httpd_oauth.erl \
-    src/couch_httpd_external.erl \
-    src/couch_httpd_misc_handlers.erl \
-    src/couch_httpd_proxy.erl \
-    src/couch_httpd_rewrite.erl \
-    src/couch_httpd_stats_handlers.erl \
-    src/couch_httpd_vhost.erl \
-    src/couch_key_tree.erl \
-    src/couch_log.erl \
-	src/couch_lru.erl \
-    src/couch_native_process.erl \
-    src/couch_os_daemons.erl \
-    src/couch_os_process.erl \
-    src/couch_passwords.erl \
-    src/couch_primary_sup.erl \
-	src/couch_proc_manager.erl \
-    src/couch_query_servers.erl \
-    src/couch_secondary_sup.erl \
-    src/couch_server.erl \
-    src/couch_stats_aggregator.erl \
-    src/couch_stats_collector.erl \
-    src/couch_stream.erl \
-    src/couch_sup.erl \
-    src/couch_task_status.erl \
-    src/couch_users_db.erl \
-    src/couch_util.erl \
-    src/couch_uuids.erl \
-    src/couch_db_updater.erl \
-    src/couch_work_queue.erl
-
-EXTRA_DIST = \
-	$(source_files) \
-	include/couch_db.hrl \
-	src/couch_js_functions.hrl
-
-compiled_files = \
-    ebin/couch.app \
-    ebin/couch.beam \
-    ebin/couch_app.beam \
-    ebin/couch_auth_cache.beam \
-    ebin/couch_btree.beam \
-    ebin/couch_changes.beam \
-    ebin/couch_compaction_daemon.beam \
-    ebin/couch_compress.beam \
-    ebin/couch_config.beam \
-    ebin/couch_config_writer.beam \
-    ebin/couch_db.beam \
-    ebin/couch_db_update_notifier.beam \
-    ebin/couch_db_update_notifier_sup.beam \
-    ebin/couch_doc.beam \
-    ebin/couch_drv.beam \
-    ebin/couch_ejson_compare.beam \
-    ebin/couch_emsort.beam \
-    ebin/couch_event_sup.beam \
-    ebin/couch_external_manager.beam \
-    ebin/couch_external_server.beam \
-    ebin/couch_file.beam \
-    ebin/couch_httpd.beam \
-    ebin/couch_httpd_db.beam \
-    ebin/couch_httpd_auth.beam \
-    ebin/couch_httpd_oauth.beam \
-    ebin/couch_httpd_cors.beam \
-    ebin/couch_httpd_proxy.beam \
-    ebin/couch_httpd_external.beam \
-    ebin/couch_httpd_misc_handlers.beam \
-    ebin/couch_httpd_rewrite.beam \
-    ebin/couch_httpd_stats_handlers.beam \
-    ebin/couch_httpd_vhost.beam \
-    ebin/couch_key_tree.beam \
-    ebin/couch_log.beam \
-	ebin/couch_lru.beam \
-    ebin/couch_native_process.beam \
-    ebin/couch_os_daemons.beam \
-    ebin/couch_os_process.beam \
-    ebin/couch_passwords.beam \
-    ebin/couch_primary_sup.beam \
-	ebin/couch_proc_manager.beam \
-    ebin/couch_query_servers.beam \
-    ebin/couch_secondary_sup.beam \
-    ebin/couch_server.beam \
-    ebin/couch_stats_aggregator.beam \
-    ebin/couch_stats_collector.beam \
-    ebin/couch_stream.beam \
-    ebin/couch_sup.beam \
-    ebin/couch_task_status.beam \
-    ebin/couch_users_db.beam \
-    ebin/couch_util.beam \
-    ebin/couch_uuids.beam \
-    ebin/couch_db_updater.beam \
-    ebin/couch_work_queue.beam
-
-# doc_base = \
-#     erlang.png \
-#     index.html \
-#     modules-frame.html \
-#     overview-summary.html \
-#     packages-frame.html \
-#     stylesheet.css
-
-# doc_modules = \
-#     couch_btree.html \
-#     couch_config.html \
-#     couch_config_writer.html \
-#     couch_db.html \
-#     couch_db_update_notifier.html \
-#     couch_db_update_notifier_sup.html \
-#     couch_doc.html \
-#     couch_event_sup.html \
-#     couch_file.html \
-#     couch_httpd.html \
-#     couch_key_tree.html \
-#     couch_log.html \
-#     couch_query_servers.html \
-#     couch_rep.html \
-#     couch_rep_sup.html \
-#     couch_server.html \
-#     couch_stream.html \
-#     couch_util.html
-
-if WINDOWS
-ebin/couch.app: src/couch.app.tpl
-	@mkdir -p ebin/
-	modules=`find ./src -name "*.erl" \! -name ".*" -exec basename {} .erl \; | tr '\n' ',' | sed "s/,$$//"`; \
-	sed -e "s|%package_name%|@package_name@|g" \
-			-e "s|%version%|@version@|g" \
-			-e "s|@modules@|$$modules|g" \
-			-e "s|%localconfdir%|../etc/couchdb|g" \
-			-e "s|@defaultini@|default.ini|g" \
-			-e "s|@localini@|local.ini|g" > \
-	$@ < $<
-else
-ebin/couch.app: src/couch.app.tpl
-	@mkdir -p ebin/
-	modules=`{ find ./src -name "*.erl" \! -name ".*" -exec basename {} .erl \; | tr '\n' ','; echo ''; } | sed "s/,$$//"`; \
-	sed -e "s|%package_name%|@package_name@|g" \
-			-e "s|%version%|@version@|g" \
-			-e "s|@modules@|$$modules|g" \
-			-e "s|%localconfdir%|@localconfdir@|g" \
-			-e "s|@defaultini@|default.ini|g" \
-			-e "s|@localini@|local.ini|g" > \
-	$@ < $<
-endif
-
-# $(dist_devdoc_DATA): edoc-info
-
-# $(ERL) -noshell -run edoc_run files [\"$<\"]
-
-ebin/%.beam: src/%.erl include/couch_db.hrl src/couch_js_functions.hrl
-	@mkdir -p ebin/
-	$(ERLC) -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) ${TEST} $<;
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch/priv/Makefile.am
----------------------------------------------------------------------
diff --git a/src/couch/priv/Makefile.am b/src/couch/priv/Makefile.am
deleted file mode 100644
index ced9bec..0000000
--- a/src/couch/priv/Makefile.am
+++ /dev/null
@@ -1,159 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-MAKE_SAFE = $(MAKE)
-
-couchlibdir = $(localerlanglibdir)/couch-$(version)
-couchprivdir = $(couchlibdir)/priv
-couchprivlibdir = $(couchlibdir)/priv/lib
-man1dir = $(mandir)/man1
-
-man_file = couchjs.1
-
-if BUILD_MAN
-man_file_build = $(man_file)
-else
-man_file_build =
-endif
-
-BUILT_SOURCES = $(man_file_build)
-
-EXTRA_DIST = \
-	spawnkillable/couchspawnkillable.sh \
-	stat_descriptions.cfg.in \
-	couch_ejson_compare/erl_nif_compat.h \
-	couch_js/sm170.c \
-	couch_js/sm180.c \
-	couch_js/sm185.c \
-	$(man_file_build)
-
-CLEANFILES = $(man_file_build) stat_descriptions.cfg
-
-couchprivlib_LTLIBRARIES = couch_icu_driver.la
-if USE_EJSON_COMPARE_NIF
-couchprivlib_LTLIBRARIES += couch_ejson_compare.la
-couch_ejson_compare_la_SOURCES = couch_ejson_compare/couch_ejson_compare.c
-couch_ejson_compare_la_CPPFLAGS = -D_BSD_SOURCE $(ICU_CPPFLAGS) $(ERLANG_FLAGS)
-couch_ejson_compare_la_LDFLAGS = -module -avoid-version
-couch_ejson_compare_la_LIBADD = $(ICU_LIBS)
-if WINDOWS
-couch_ejson_compare_la_LDFLAGS += -no-undefined
-endif
-endif
-couch_icu_driver_la_SOURCES = icu_driver/couch_icu_driver.c
-couch_icu_driver_la_LDFLAGS = -module -avoid-version
-couch_icu_driver_la_CPPFLAGS = $(ICU_CPPFLAGS) $(ERLANG_FLAGS)
-couch_icu_driver_la_LIBADD = $(ICU_LIBS)
-
-if WINDOWS
-couch_icu_driver_la_LDFLAGS += -no-undefined
-couch_icu_driver_so_name = couch_icu_driver.dll
-else
-couch_icu_driver_so_name = couch_icu_driver.so
-endif
-
-$(couch_icu_driver_so_name): couch_icu_driver.la
-	cp .libs/$(couch_icu_driver_so_name) $@
-
-all: $(couch_icu_driver_so_name)
-
-COUCHJS_SRCS = \
-	couch_js/help.h \
-	couch_js/http.c \
-	couch_js/http.h \
-	couch_js/main.c \
-	couch_js/utf8.c \
-	couch_js/utf8.h \
-	couch_js/util.h \
-	couch_js/util.c
-
-locallibbin_PROGRAMS = couchjs
-couchjs_SOURCES = $(COUCHJS_SRCS)
-couchjs_CFLAGS = -g -Wall -Werror -D_BSD_SOURCE $(CURL_CFLAGS) $(JS_CFLAGS)
-couchjs_LDADD = $(CURL_LIBS) $(JS_LIBS)
-
-couchpriv_DATA = stat_descriptions.cfg
-couchpriv_PROGRAMS = couchspawnkillable
-
-# Depend on source files so distributed man pages are not rebuilt for end user.
-
-$(man_file): $(COUCHJS_SRCS)
-	$(MAKE_SAFE) -f Makefile couchjs; \
-	$(top_srcdir)/build-aux/missing --run \
-	    help2man \
-	        --no-info \
-	        --help-option="-h" \
-	        --version-option="-V" \
-	        --name="$(package_name) JavaScript interpreter" \
-	        ./couchjs --output $@
-
-install-data-local:
-	if test -s $(man_file); then \
-	    if test `cat $(man_file) | wc -l` -gt 1; then \
-	        $(INSTALL) -d $(DESTDIR)$(man1dir); \
-	        $(INSTALL_DATA) $(man_file) $(DESTDIR)$(man1dir)/$(man_file); \
-	    fi \
-	fi
-
-%.cfg: %.cfg.in
-	cp $< $@
-
-if WINDOWS
-couchspawnkillable_SOURCES = spawnkillable/couchspawnkillable_win.c
-endif
-
-if !WINDOWS
-couchspawnkillable: spawnkillable/couchspawnkillable.sh
-	cp $< $@
-	chmod +x $@
-endif
-
-# libtool and automake have defeated markh.  For each of our executables
-# we end up with 2 copies - one directly in the 'target' folder (eg, 'priv')
-# and another - the correct one - in .libs.  The former doesn't work but is
-# what gets installed for 'couchspawnkillable' - but the correct one for
-# couchjs.exe *does* get copied.  *shrug*  So just clobber it with the
-# correct one as the last step. See bug COUCHDB-439
-install-data-hook:
-	if test -f "$(DESTDIR)$(couchprivlibdir)/couch_icu_driver"; then \
-	    rm -f "$(DESTDIR)$(couchprivlibdir)/couch_icu_driver.so"; \
-	    cd "$(DESTDIR)$(couchprivlibdir)" && \
-	        $(LN_S) couch_icu_driver couch_icu_driver.so; \
-	fi
-	if test -f "$(DESTDIR)$(couchprivlibdir)/couch_ejson_compare_nif"; then \
-	    rm -f "$(DESTDIR)$(couchprivlibdir)/couch_ejson_compare_nif.so"; \
-	    cd "$(DESTDIR)$(couchprivlibdir)" && \
-	        $(LN_S) couch_ejson_compare_nif couch_ejson_compare_nif.so; \
-	fi
-if WINDOWS
-	$(INSTALL) $(ICU_BIN)/icuuc*.dll $(bindir)
-	$(INSTALL) $(ICU_BIN)/icudt*.dll $(bindir)
-	$(INSTALL) $(ICU_BIN)/icuin*.dll $(bindir)
-	$(INSTALL) $(JS_LIB_BINARY) $(bindir)
-	$(INSTALL) .libs/couchspawnkillable.exe \
-		"$(DESTDIR)$(couchprivdir)/couchspawnkillable.exe"
-endif
-
-uninstall-local:
-	rm -f $(DESTDIR)$(man1dir)/$(man_file)
-	if test -f "$(DESTDIR)$(couchprivlibdir)/couch_erl_driver"; then \
-	    rm -f "$(DESTDIR)$(couchprivlibdir)/couch_erl_driver.so"; \
-	fi
-
-distcheck-hook:
-	if test ! -s $(man_file); then \
-	    $(top_srcdir)/build-aux/dist-error $(man_file); \
-	else \
-	    if test ! `cat $(man_file) | wc -l` -gt 1; then \
-	        $(top_srcdir)/build-aux/dist-error $(man_file); \
-	    fi \
-	fi

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch/src/couch.app.src
----------------------------------------------------------------------
diff --git a/src/couch/src/couch.app.src b/src/couch/src/couch.app.src
new file mode 100644
index 0000000..0cc3b54
--- /dev/null
+++ b/src/couch/src/couch.app.src
@@ -0,0 +1,22 @@
+{application, couch, [
+    {description, "Apache CouchDB"},
+    {vsn, git},
+    {registered, [
+        couch_db_update,
+        couch_db_update_notifier_sup,
+        couch_external_manager,
+        couch_httpd,
+        couch_log,
+        couch_primary_services,
+        couch_proc_manager,
+        couch_secondary_services,
+        couch_server,
+        couch_sup,
+        couch_stats_aggregator,
+        couch_stats_collector,
+        couch_task_status
+    ]},
+    {mod, {couch_app, []}},
+    {applications, [kernel, stdlib, crypto, sasl, inets, oauth, ibrowse,
+        mochiweb, ssl, twig, couch_event]}
+]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch/src/couch.app.tpl.in
----------------------------------------------------------------------
diff --git a/src/couch/src/couch.app.tpl.in b/src/couch/src/couch.app.tpl.in
deleted file mode 100644
index 9b7536b..0000000
--- a/src/couch/src/couch.app.tpl.in
+++ /dev/null
@@ -1,26 +0,0 @@
-{application, couch, [
-    {description, "@package_name@"},
-    {vsn, "@version@"},
-    {modules, [@modules@]},
-    {registered, [
-        couch_db_update,
-        couch_db_update_notifier_sup,
-        couch_external_manager,
-        couch_httpd,
-        couch_log,
-        couch_primary_services,
-        couch_proc_manager,
-        couch_secondary_services,
-        couch_server,
-        couch_sup,
-        couch_stats_aggregator,
-        couch_stats_collector,
-        couch_task_status
-    ]},
-    {mod, {couch_app, [
-        "%localconfdir%/@defaultini@",
-        "%localconfdir%/@localini@"
-    ]}},
-    {applications, [kernel, stdlib, twig, config]},
-    {included_applications, [crypto, sasl, inets, oauth, ibrowse, mochiweb, os_mon]}
-]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_index/Makefile.am
----------------------------------------------------------------------
diff --git a/src/couch_index/Makefile.am b/src/couch_index/Makefile.am
deleted file mode 100644
index 945623a..0000000
--- a/src/couch_index/Makefile.am
+++ /dev/null
@@ -1,38 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-couch_indexlibdir = $(localerlanglibdir)/couch_index-0.1
-couch_indexebindir = $(couch_indexlibdir)/ebin
-
-couch_indexebin_DATA = $(compiled_files)
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-source_files = \
-    src/couch_index.erl \
-    src/couch_index_compactor.erl \
-    src/couch_index_server.erl \
-    src/couch_index_updater.erl \
-	src/couch_index_util.erl
-
-compiled_files = \
-    ebin/couch_index.beam \
-    ebin/couch_index_compactor.beam \
-    ebin/couch_index_server.beam \
-    ebin/couch_index_updater.beam \
-	ebin/couch_index_util.beam
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) ${TEST} $<;
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_index/src/couch_index.app.src
----------------------------------------------------------------------
diff --git a/src/couch_index/src/couch_index.app.src b/src/couch_index/src/couch_index.app.src
index 141ed9d..594589d 100644
--- a/src/couch_index/src/couch_index.app.src
+++ b/src/couch_index/src/couch_index.app.src
@@ -12,7 +12,7 @@
 
 {application, couch_index, [
     {description, "CouchDB Secondary Index Manager"},
-    {vsn, "@version@"},
+    {vsn, git},
     {modules, [
         couch_index,
         couch_index_server

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_mrview/Makefile.am
----------------------------------------------------------------------
diff --git a/src/couch_mrview/Makefile.am b/src/couch_mrview/Makefile.am
deleted file mode 100644
index fa7d83b..0000000
--- a/src/couch_mrview/Makefile.am
+++ /dev/null
@@ -1,72 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-couch_mrviewlibdir = $(localerlanglibdir)/couch_mrview-0.1
-couch_mrviewincludedir = $(couch_mrviewlibdir)/include
-couch_mrviewebindir = $(couch_mrviewlibdir)/ebin
-
-couch_mrviewinclude_DATA = $(include_files)
-couch_mrviewebin_DATA = $(compiled_files)
-
-include_files = \
-    include/couch_mrview.hrl
-
-source_files = \
-    src/couch_mrview.app.src \
-    src/couch_mrview.erl \
-    src/couch_mrview_cleanup.erl \
-    src/couch_mrview_compactor.erl \
-    src/couch_mrview_http.erl \
-    src/couch_mrview_index.erl \
-    src/couch_mrview_show.erl \
-    src/couch_mrview_test_util.erl \
-    src/couch_mrview_updater.erl \
-    src/couch_mrview_util.erl
-
-test_files = \
-    test/01-load.t \
-    test/02-map-views.t \
-    test/03-red-views.t \
-    test/04-index-info.t \
-    test/05-collation.t \
-    test/06-all-docs.t \
-	test/07-compact-swap.t
-
-compiled_files = \
-    ebin/couch_mrview.app \
-    ebin/couch_mrview.beam \
-    ebin/couch_mrview_cleanup.beam \
-    ebin/couch_mrview_compactor.beam \
-    ebin/couch_mrview_http.beam \
-    ebin/couch_mrview_index.beam \
-    ebin/couch_mrview_show.beam \
-    ebin/couch_mrview_test_util.beam \
-    ebin/couch_mrview_updater.beam \
-    ebin/couch_mrview_util.beam
-
-EXTRA_DIST = $(include_files) $(source_files) $(test_files)
-CLEANFILES = $(compiled_files)
-
-check:
-if TESTS
-	$(abs_top_builddir)/test/etap/run $(abs_top_srcdir)/src/couch_mrview/test
-endif
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" \
-	< $< > $@
-
-ebin/%.beam: src/%.erl $(include_files)
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) ${TEST} $<;
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_mrview/include/couch_mrview.hrl
----------------------------------------------------------------------
diff --git a/src/couch_mrview/include/couch_mrview.hrl b/src/couch_mrview/include/couch_mrview.hrl
index 0d59066..6a0dfd0 100644
--- a/src/couch_mrview/include/couch_mrview.hrl
+++ b/src/couch_mrview/include/couch_mrview.hrl
@@ -70,11 +70,13 @@
     skip = 0,
     group_level = 0,
     stale = false,
+    multi_get = false,
     inclusive_end = true,
     include_docs = false,
     update_seq=false,
     conflicts,
     callback,
     list,
+    sorted = true,
     extra = []
 }).

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_mrview/src/couch_mrview.app.src
----------------------------------------------------------------------
diff --git a/src/couch_mrview/src/couch_mrview.app.src b/src/couch_mrview/src/couch_mrview.app.src
index 52898a6..99c52f0 100644
--- a/src/couch_mrview/src/couch_mrview.app.src
+++ b/src/couch_mrview/src/couch_mrview.app.src
@@ -12,7 +12,7 @@
 
 {application, couch_mrview, [
     {description, "CouchDB Map/Reduce Views"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         couch_mrview,
         couch_mrview_compactor,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_replicator/.gitignore
----------------------------------------------------------------------
diff --git a/src/couch_replicator/.gitignore b/src/couch_replicator/.gitignore
deleted file mode 100644
index b3099f5..0000000
--- a/src/couch_replicator/.gitignore
+++ /dev/null
@@ -1,4 +0,0 @@
-*.beam
-.eunit
-ebin/replicator.app
-.DS_Store
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_replicator/Makefile.am
----------------------------------------------------------------------
diff --git a/src/couch_replicator/Makefile.am b/src/couch_replicator/Makefile.am
deleted file mode 100644
index ea5d117..0000000
--- a/src/couch_replicator/Makefile.am
+++ /dev/null
@@ -1,76 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-couch_replicatorlibdir = $(localerlanglibdir)/couch_replicator-0.1
-couch_replicatorincludedir = $(couch_replicatorlibdir)/include
-couch_replicatorebindir = $(couch_replicatorlibdir)/ebin
-
-couch_replicatorinclude_DATA = $(include_files)
-couch_replicatorebin_DATA = $(compiled_files)
-
-include_files = \
-	src/couch_replicator_api_wrap.hrl \
-	src/couch_replicator.hrl \
-	src/couch_replicator_js_functions.hrl
-
-source_files = \
-	src/couch_replicator_api_wrap.erl \
-	src/couch_replicator_httpc_pool.erl \
-	src/couch_replicator_httpc.erl \
-	src/couch_replicator_httpd.erl \
-	src/couch_replicator_job_sup.erl \
-	src/couch_replicator_notifier.erl \
-	src/couch_replicator_manager.erl \
-	src/couch_replicator_utils.erl \
-	src/couch_replicator_worker.erl \
-	src/couch_replicator.app.src \
-	src/couch_replicator.erl
-
-test_files = \
-	test/01-load.t \
-	test/02-httpc-pool.t \
-	test/03-replication-compact.t \
-	test/04-replication-large-atts.t \
-	test/05-replication-many-leaves.t \
-	test/06-doc-missing-stubs.t
-
-compiled_files = \
-	ebin/couch_replicator_api_wrap.beam \
-	ebin/couch_replicator_httpc_pool.beam \
-	ebin/couch_replicator_httpc.beam \
-	ebin/couch_replicator_httpd.beam \
-	ebin/couch_replicator_job_sup.beam \
-	ebin/couch_replicator_notifier.beam \
-	ebin/couch_replicator_manager.beam \
-	ebin/couch_replicator_utils.beam \
-	ebin/couch_replicator_worker.beam \
-	ebin/couch_replicator.app \
-	ebin/couch_replicator.beam
-
-EXTRA_DIST = $(include_files) $(source_files) $(test_files)
-CLEANFILES = $(compiled_files)
-
-check:
-if TESTS
-	$(abs_top_builddir)/test/etap/run $(abs_top_srcdir)/src/couch_replicator/test
-endif
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" \
-	< $< > $@
-
-ebin/%.beam: src/%.erl $(include_files)
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) ${TEST} $<;
-
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/couch_replicator/src/couch_replicator.app.src
----------------------------------------------------------------------
diff --git a/src/couch_replicator/src/couch_replicator.app.src b/src/couch_replicator/src/couch_replicator.app.src
index bd6b3e3..2da0d4a 100644
--- a/src/couch_replicator/src/couch_replicator.app.src
+++ b/src/couch_replicator/src/couch_replicator.app.src
@@ -12,7 +12,7 @@
 
 {application, couch_replicator, [
     {description, "CouchDB replicator"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         couch_replicator,
         couch_replicator_api_wrap,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ddoc_cache/.gitignore
----------------------------------------------------------------------
diff --git a/src/ddoc_cache/.gitignore b/src/ddoc_cache/.gitignore
deleted file mode 100644
index fc83a9a..0000000
--- a/src/ddoc_cache/.gitignore
+++ /dev/null
@@ -1 +0,0 @@
-ebin/

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ddoc_cache/Makefile.am
----------------------------------------------------------------------
diff --git a/src/ddoc_cache/Makefile.am b/src/ddoc_cache/Makefile.am
deleted file mode 100644
index 6936545..0000000
--- a/src/ddoc_cache/Makefile.am
+++ /dev/null
@@ -1,42 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-ddoc_cacheebindir = $(localerlanglibdir)/ddoc_cache/ebin
-
-ddoc_cacheebin_DATA = $(compiled_files)
-
-source_files = \
-	src/ddoc_cache.app.src \
-    src/ddoc_cache.erl \
-	src/ddoc_cache_app.erl \
-	src/ddoc_cache_opener.erl \
-	src/ddoc_cache_sup.erl \
-	src/ddoc_cache_util.erl
-
-compiled_files = \
-	ebin/ddoc_cache.app \
-    ebin/ddoc_cache.beam \
-	ebin/ddoc_cache_app.beam \
-	ebin/ddoc_cache_opener.beam \
-	ebin/ddoc_cache_sup.beam \
-	ebin/ddoc_cache_util.beam
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ddoc_cache/src/ddoc_cache.app.src
----------------------------------------------------------------------
diff --git a/src/ddoc_cache/src/ddoc_cache.app.src b/src/ddoc_cache/src/ddoc_cache.app.src
index 78f45de..a183dbd 100644
--- a/src/ddoc_cache/src/ddoc_cache.app.src
+++ b/src/ddoc_cache/src/ddoc_cache.app.src
@@ -12,7 +12,7 @@
 
 {application, ddoc_cache, [
     {description, "Design Document Cache"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         ddoc_cache,
         ddoc_cache_app,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ejson/Makefile.am
----------------------------------------------------------------------
diff --git a/src/ejson/Makefile.am b/src/ejson/Makefile.am
deleted file mode 100644
index 21136fb..0000000
--- a/src/ejson/Makefile.am
+++ /dev/null
@@ -1,91 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-ejsonebindir = $(localerlanglibdir)/ejson-0.1.0/ebin
-ejsonprivdir = $(localerlanglibdir)/ejson-0.1.0/priv
-
-CLEANFILES = \
-    $(ejsonebin_make_generated_file_list) \
-    $(ejsonpriv_make_generated_file_list) \
-    priv/ejson.so
-
-EJSON_C_SRCS = \
-	c_src/ejson.c \
-	c_src/decode.c \
-	c_src/encode.c \
-	c_src/yajl/yajl_alloc.c \
-	c_src/yajl/yajl_buf.c \
-	c_src/yajl/yajl.c \
-	c_src/yajl/yajl_encode.c \
-	c_src/yajl/yajl_gen.c \
-	c_src/yajl/yajl_lex.c \
-	c_src/yajl/yajl_parser.c
-
-EJSON_C_HDRS = \
-    c_src/erl_nif_compat.h \
-    c_src/yajl/yajl_alloc.h \
-    c_src/yajl/yajl_buf.h \
-    c_src/yajl/yajl_bytestack.h \
-    c_src/yajl/yajl_common.h \
-    c_src/yajl/yajl_encode.h \
-    c_src/yajl/yajl_gen.h \
-    c_src/yajl/yajl_lex.h \
-    c_src/yajl/yajl_parse.h \
-    c_src/yajl/yajl_parser.h
-
-ejson_file_collection = \
-    src/ejson.app.in \
-    src/ejson.erl \
-    src/mochijson2.erl \
-    src/mochinum.erl
-
-ejsonebin_make_generated_file_list = \
-    ebin/ejson.app \
-    ebin/ejson.beam \
-    ebin/mochijson2.beam \
-    ebin/mochinum.beam
-
-EXTRA_DIST = \
-	$(EJSON_C_HDRS) \
-	$(ejson_file_collection)
-
-ejsonebin_DATA = \
-    $(ejsonebin_make_generated_file_list)
-
-if USE_OTP_NIFS
-ejsonpriv_LTLIBRARIES = ejson.la
-
-ejson_la_SOURCES = $(EJSON_C_SRCS)
-ejson_la_CFLAGS = $(ERLANG_FLAGS)
-ejson_la_LDFLAGS = -module -avoid-version
-
-if WINDOWS
-ejson_la_LDFLAGS += -no-undefined
-EJSON_SO_NAME = ejson.dll
-else
-EJSON_SO_NAME = ejson.so
-endif
-
-priv/$(EJSON_SO_NAME): ejson.la
-	@mkdir -p ./priv
-	cp .libs/$(EJSON_SO_NAME) $@
-
-all: priv/$(EJSON_SO_NAME)
-endif
-
-ebin/%.app: src/%.app.in
-	@mkdir -p ebin/
-	cp $< $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) $(ERLC_FLAGS) -o ebin/ $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ejson/src/ejson.app.in
----------------------------------------------------------------------
diff --git a/src/ejson/src/ejson.app.in b/src/ejson/src/ejson.app.in
deleted file mode 100644
index c2920e9..0000000
--- a/src/ejson/src/ejson.app.in
+++ /dev/null
@@ -1,9 +0,0 @@
-{application, ejson, [
-    {description, "EJSON - decode and encode JSON into/from Erlang terms"},
-    {vsn, "0.1.0"},
-    {modules, [ejson]},
-    {registered, []},
-    {applications, [kernel, stdlib]},
-    {env, []}
-]}.
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ejson/src/ejson.app.src
----------------------------------------------------------------------
diff --git a/src/ejson/src/ejson.app.src b/src/ejson/src/ejson.app.src
new file mode 100644
index 0000000..7180b81
--- /dev/null
+++ b/src/ejson/src/ejson.app.src
@@ -0,0 +1,9 @@
+{application, ejson, [
+    {description, "EJSON - decode and encode JSON into/from Erlang terms"},
+    {vsn, git},
+    {modules, [ejson]},
+    {registered, []},
+    {applications, [kernel, stdlib]},
+    {env, []}
+]}.
+

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ets_lru/.gitignore
----------------------------------------------------------------------
diff --git a/src/ets_lru/.gitignore b/src/ets_lru/.gitignore
deleted file mode 100644
index 90bd4cb..0000000
--- a/src/ets_lru/.gitignore
+++ /dev/null
@@ -1,5 +0,0 @@
-erl_crash.dump
-
-.eunit/
-ebin/
-test/*.beam

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ets_lru/Makefile.am
----------------------------------------------------------------------
diff --git a/src/ets_lru/Makefile.am b/src/ets_lru/Makefile.am
deleted file mode 100644
index 5fd6c7b..0000000
--- a/src/ets_lru/Makefile.am
+++ /dev/null
@@ -1,34 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-ets_lruebindir = $(localerlanglibdir)/ets_lru/ebin
-
-ets_lruebin_DATA = $(compiled_files)
-
-source_files = \
-	src/ets_lru.app.src \
-    src/ets_lru.erl
-
-compiled_files = \
-	ebin/ets_lru.app \
-    ebin/ets_lru.beam
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ets_lru/src/ets_lru.app.src
----------------------------------------------------------------------
diff --git a/src/ets_lru/src/ets_lru.app.src b/src/ets_lru/src/ets_lru.app.src
index 603c5d6..2573a0f 100644
--- a/src/ets_lru/src/ets_lru.app.src
+++ b/src/ets_lru/src/ets_lru.app.src
@@ -12,7 +12,7 @@
 
 {application, ets_lru, [
     {description, "ETS Base LRU Cache"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         ets_lru
     ]},

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/.gitignore
----------------------------------------------------------------------
diff --git a/src/fabric/.gitignore b/src/fabric/.gitignore
deleted file mode 100644
index 37bfdb0..0000000
--- a/src/fabric/.gitignore
+++ /dev/null
@@ -1,4 +0,0 @@
-*.beam
-.eunit
-ebin/fabric.app
-.DS_Store
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/Makefile.am
----------------------------------------------------------------------
diff --git a/src/fabric/Makefile.am b/src/fabric/Makefile.am
deleted file mode 100644
index 64ca935..0000000
--- a/src/fabric/Makefile.am
+++ /dev/null
@@ -1,77 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-fabricebindir = $(localerlanglibdir)/fabric/ebin
-
-fabricebin_DATA = $(compiled_files)
-
-source_files = \
-    src/fabric.app.src \
-    src/fabric.erl \
-    src/fabric_db_create.erl \
-    src/fabric_db_delete.erl \
-    src/fabric_db_doc_count.erl \
-    src/fabric_db_info.erl \
-    src/fabric_db_meta.erl \
-    src/fabric_db_update_listener.erl \
-    src/fabric_dict.erl \
-    src/fabric_doc_attachments.erl \
-    src/fabric_doc_missing_revs.erl \
-    src/fabric_doc_open.erl \
-    src/fabric_doc_open_revs.erl \
-    src/fabric_doc_update.erl \
-    src/fabric_group_info.erl \
-    src/fabric_rpc.erl \
-    src/fabric_util.erl \
-    src/fabric_view.erl \
-    src/fabric_view_all_docs.erl \
-    src/fabric_view_changes.erl \
-    src/fabric_view_map.erl \
-    src/fabric_view_reduce.erl
-
-compiled_files = \
-    ebin/fabric.app \
-    ebin/fabric.beam \
-    ebin/fabric_db_create.beam \
-    ebin/fabric_db_delete.beam \
-    ebin/fabric_db_doc_count.beam \
-    ebin/fabric_db_info.beam \
-    ebin/fabric_db_meta.beam \
-    ebin/fabric_db_update_listener.beam \
-    ebin/fabric_dict.beam \
-    ebin/fabric_doc_attachments.beam \
-    ebin/fabric_doc_missing_revs.beam \
-    ebin/fabric_doc_open.beam \
-    ebin/fabric_doc_open_revs.beam \
-    ebin/fabric_doc_update.beam \
-    ebin/fabric_group_info.beam \
-    ebin/fabric_util.beam
-
-# Conflicts in couch_db.hrl prevent us from building these
-# until after we merge the couch application
-#   ebin/fabric_rpc.beam
-#	ebin/fabric_view.beam
-#	ebin/fabric_view_all_docs.beam
-#	ebin/fabric_view_changes.beam
-#	ebin/fabric_view_map.beam
-#	ebin/fabric_view_reduce.beam
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/src/fabric.app.src
----------------------------------------------------------------------
diff --git a/src/fabric/src/fabric.app.src b/src/fabric/src/fabric.app.src
index a3022e6..5ac86ef 100644
--- a/src/fabric/src/fabric.app.src
+++ b/src/fabric/src/fabric.app.src
@@ -12,7 +12,7 @@
 
 {application, fabric, [
     {description, "Routing and proxying layer for CouchDB cluster"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         fabric,
         fabric_db_create,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/src/fabric_rpc.erl
----------------------------------------------------------------------
diff --git a/src/fabric/src/fabric_rpc.erl b/src/fabric/src/fabric_rpc.erl
index 4926609..2685cd7 100644
--- a/src/fabric/src/fabric_rpc.erl
+++ b/src/fabric/src/fabric_rpc.erl
@@ -22,6 +22,7 @@
 
 -include_lib("fabric/include/fabric.hrl").
 -include_lib("couch/include/couch_db.hrl").
+-include_lib("couch_mrview/include/couch_mrview.hrl").
 
 -record (view_acc, {
     db,
@@ -38,13 +39,13 @@
 %% rpc endpoints
 %%  call to with_db will supply your M:F with a #db{} and then remaining args
 
-all_docs(DbName, #view_query_args{keys=nil} = QueryArgs) ->
+all_docs(DbName, #mrargs{keys=nil} = QueryArgs) ->
     {ok, Db} = get_or_create_db(DbName, []),
-    #view_query_args{
+    #mrargs{
         start_key = StartKey,
-        start_docid = StartDocId,
+        start_key_docid = StartDocId,
         end_key = EndKey,
-        end_docid = EndDocId,
+        end_key_docid = EndDocId,
         limit = Limit,
         skip = Skip,
         include_docs = IncludeDocs,
@@ -93,7 +94,7 @@ changes(DbName, Options, StartSeq) ->
 
 map_view(DbName, DDoc, ViewName, QueryArgs) ->
     {ok, Db} = get_or_create_db(DbName, []),
-    #view_query_args{
+    #mrargs{
         limit = Limit,
         skip = Skip,
         keys = Keys,
@@ -126,7 +127,7 @@ map_view(DbName, DDoc, ViewName, QueryArgs) ->
         {ok, _, Acc} = couch_view:fold(View, fun view_fold/3, Acc0, Options);
     _ ->
         Acc = lists:foldl(fun(Key, AccIn) ->
-            KeyArgs = QueryArgs#view_query_args{start_key=Key, end_key=Key},
+            KeyArgs = QueryArgs#mrargs{start_key=Key, end_key=Key},
             Options = couch_httpd_view:make_key_options(KeyArgs),
             {_Go, _, Out} = couch_view:fold(View, fun view_fold/3, AccIn,
                 Options),
@@ -141,7 +142,7 @@ reduce_view(DbName, #doc{} = DDoc, ViewName, QueryArgs) ->
 reduce_view(DbName, Group0, ViewName, QueryArgs) ->
     erlang:put(io_priority, {interactive, DbName}),
     {ok, Db} = get_or_create_db(DbName, []),
-    #view_query_args{
+    #mrargs{
         group_level = GroupLevel,
         limit = Limit,
         skip = Skip,
@@ -168,7 +169,7 @@ reduce_view(DbName, Group0, ViewName, QueryArgs) ->
         couch_view:fold_reduce(ReduceView, fun reduce_fold/3, Acc0, Options);
     _ ->
         lists:map(fun(Key) ->
-            KeyArgs = QueryArgs#view_query_args{start_key=Key, end_key=Key},
+            KeyArgs = QueryArgs#mrargs{start_key=Key, end_key=Key},
             Options0 = couch_httpd_view:make_key_options(KeyArgs),
             Options = [{key_group_fun, GroupFun} | Options0],
             couch_view:fold_reduce(ReduceView, fun reduce_fold/3, Acc0, Options)

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/src/fabric_view.erl
----------------------------------------------------------------------
diff --git a/src/fabric/src/fabric_view.erl b/src/fabric/src/fabric_view.erl
index a42582b..9cb4b03 100644
--- a/src/fabric/src/fabric_view.erl
+++ b/src/fabric/src/fabric_view.erl
@@ -19,6 +19,7 @@
 -include_lib("fabric/include/fabric.hrl").
 -include_lib("mem3/include/mem3.hrl").
 -include_lib("couch/include/couch_db.hrl").
+-include_lib("couch_mrview/include/couch_mrview.hrl").
 
 -spec remove_down_shards(#collector{}, node()) ->
     {ok, #collector{}} | {error, any()}.
@@ -139,7 +140,7 @@ possibly_embed_doc(_State,
     Row;
 possibly_embed_doc(#collector{db_name=DbName, query_args=Args},
               #view_row{key=_Key, id=_Id, value=Value, doc=_Doc}=Row) ->
-    #view_query_args{include_docs=IncludeDocs} = Args,
+    #mrargs{include_docs=IncludeDocs} = Args,
     case IncludeDocs andalso is_tuple(Value) of
     true ->
         {Props} = Value,
@@ -190,7 +191,7 @@ get_next_row(#collector{rows = []}) ->
     throw(complete);
 get_next_row(#collector{reducer = RedSrc} = St) when RedSrc =/= undefined ->
     #collector{
-        query_args = #view_query_args{direction=Dir},
+        query_args = #mrargs{direction=Dir},
         keys = Keys,
         rows = RowDict,
         os_proc = Proc,
@@ -269,9 +270,9 @@ extract_view(Pid, ViewName, [View|Rest], ViewType) ->
     end.
 
 view_names(View, Type) when Type == red_map; Type == reduce ->
-    [Name || {Name, _} <- View#view.reduce_funs];
+    [Name || {Name, _} <- View#mrview.reduce_funs];
 view_names(View, map) ->
-    View#view.map_names.
+    View#mrview.map_names.
 
 index_of(X, List) ->
     index_of(X, List, 1).
@@ -283,10 +284,10 @@ index_of(X, [X|_Rest], I) ->
 index_of(X, [_|Rest], I) ->
     index_of(X, Rest, I+1).
 
-get_shards(DbName, #view_query_args{stale=Stale})
+get_shards(DbName, #mrargs{stale=Stale})
   when Stale == ok orelse Stale == update_after ->
     mem3:ushards(DbName);
-get_shards(DbName, #view_query_args{stale=false}) ->
+get_shards(DbName, #mrargs{stale=false}) ->
     mem3:shards(DbName).
 
 % unit test

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/fabric/src/fabric_view_reduce.erl
----------------------------------------------------------------------
diff --git a/src/ibrowse/Makefile.am b/src/ibrowse/Makefile.am
deleted file mode 100644
index 533a27f..0000000
--- a/src/ibrowse/Makefile.am
+++ /dev/null
@@ -1,51 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-ibrowseebindir = $(localerlanglibdir)/ibrowse-2.2.0/ebin
-
-ibrowse_file_collection = \
-	src/ibrowse.app.in \
-	src/ibrowse.erl \
-	src/ibrowse_app.erl \
-	src/ibrowse_http_client.erl \
-	src/ibrowse_lb.erl \
-	src/ibrowse_lib.erl \
-	src/ibrowse_sup.erl \
-	src/ibrowse_test.erl
-
-ibrowseebin_make_generated_file_list = \
-	ebin/ibrowse.app \
-	ebin/ibrowse.beam \
-	ebin/ibrowse_app.beam \
-	ebin/ibrowse_http_client.beam \
-	ebin/ibrowse_lb.beam \
-	ebin/ibrowse_lib.beam \
-	ebin/ibrowse_sup.beam \
-	ebin/ibrowse_test.beam
-
-ibrowseebin_DATA = \
-    $(ibrowseebin_make_generated_file_list)
-
-EXTRA_DIST =  \
-    $(ibrowse_file_collection) \
-    include/ibrowse.hrl
-
-CLEANFILES = \
-    $(ibrowseebin_make_generated_file_list)
-
-ebin/%.app: src/%.app.in
-	@mkdir -p ebin/
-	cp $< $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -o ebin/ -I$(top_srcdir)/src $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ibrowse/src/ibrowse.app.in
----------------------------------------------------------------------
diff --git a/src/ibrowse/src/ibrowse.app.in b/src/ibrowse/src/ibrowse.app.in
deleted file mode 100644
index 1d88084..0000000
--- a/src/ibrowse/src/ibrowse.app.in
+++ /dev/null
@@ -1,7 +0,0 @@
-{application, ibrowse,
-        [{description, "Erlang HTTP client application"},
-         {vsn, "4.0.1"},
-         {registered, [ibrowse_sup, ibrowse]},
-         {applications, [kernel,stdlib]},
-	 {env, []},
-	 {mod, {ibrowse_app, []}}]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ibrowse/src/ibrowse.app.src
----------------------------------------------------------------------
diff --git a/src/ibrowse/src/ibrowse.app.src b/src/ibrowse/src/ibrowse.app.src
new file mode 100644
index 0000000..f65ba44
--- /dev/null
+++ b/src/ibrowse/src/ibrowse.app.src
@@ -0,0 +1,7 @@
+{application, ibrowse,
+        [{description, "Erlang HTTP client application"},
+         {vsn, git},
+         {registered, [ibrowse_sup, ibrowse]},
+         {applications, [kernel,stdlib]},
+	 {env, []},
+	 {mod, {ibrowse_app, []}}]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mem3/.gitignore
----------------------------------------------------------------------
diff --git a/src/mem3/.gitignore b/src/mem3/.gitignore
deleted file mode 100644
index e16ee29..0000000
--- a/src/mem3/.gitignore
+++ /dev/null
@@ -1,4 +0,0 @@
-ebin/*.beam
-ebin/*.app
-TEST-*
-.eunit

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mem3/Makefile.am
----------------------------------------------------------------------
diff --git a/src/mem3/Makefile.am b/src/mem3/Makefile.am
deleted file mode 100644
index cf732ab..0000000
--- a/src/mem3/Makefile.am
+++ /dev/null
@@ -1,60 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-mem3ebindir = $(localerlanglibdir)/mem3/ebin
-
-mem3ebin_DATA = $(compiled_files)
-
-source_files = \
-	src/mem3.app.src \
-    src/mem3.erl \
-	src/mem3_app.erl \
-	src/mem3_httpd.erl \
-	src/mem3_nodes.erl \
-	src/mem3_rep.erl \
-	src/mem3_shards.erl \
-	src/mem3_sup.erl \
-	src/mem3_sync.erl \
-	src/mem3_sync_event.erl \
-	src/mem3_sync_nodes.erl \
-	src/mem3_sync_security.erl \
-	src/mem3_util.erl
-
-compiled_files = \
-	ebin/mem3.app \
-    ebin/mem3.beam \
-	ebin/mem3_app.beam \
-	ebin/mem3_httpd.beam \
-	ebin/mem3_shards.beam \
-	ebin/mem3_sup.beam \
-	ebin/mem3_sync.beam \
-	ebin/mem3_sync_event.beam \
-	ebin/mem3_sync_nodes.beam \
-	ebin/mem3_sync_security.beam \
-	ebin/mem3_util.beam
-
-# Conflicts in couch_db.hrl prevent us from building these
-# until after we merge the couch application
-#	ebin/mem3_nodes.beam
-#	ebin/mem3_rep.beam
-
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mem3/src/mem3.app.src
----------------------------------------------------------------------
diff --git a/src/mem3/src/mem3.app.src b/src/mem3/src/mem3.app.src
index 612a7fb..616e4bd 100644
--- a/src/mem3/src/mem3.app.src
+++ b/src/mem3/src/mem3.app.src
@@ -12,7 +12,7 @@
 
 {application, mem3, [
     {description, "CouchDB Cluster Membership"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         mem3,
         mem3_app,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mochiweb/Makefile.am
----------------------------------------------------------------------
diff --git a/src/mochiweb/Makefile.am b/src/mochiweb/Makefile.am
deleted file mode 100644
index 655f0ab..0000000
--- a/src/mochiweb/Makefile.am
+++ /dev/null
@@ -1,113 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-if USE_NATIVE_MOCHIJSON
-MOCHIJSON_ERLC_FLAGS=+native
-endif
-
-mochiwebebindir = $(localerlanglibdir)/mochiweb-1.4.1/ebin
-
-mochiweb_file_collection = \
-	src/mochifmt.erl \
-	src/mochifmt_records.erl \
-	src/mochifmt_std.erl \
-	src/mochiglobal.erl \
-	src/mochihex.erl \
-	src/mochijson.erl \
-	src/mochijson2.erl \
-	src/mochilists.erl \
-	src/mochilogfile2.erl \
-	src/mochinum.erl \
-	src/mochitemp.erl \
-	src/mochiutf8.erl \
-	src/mochiweb.app.in \
-	src/mochiweb.app.src \
-	src/mochiweb.erl \
-	src/mochiweb_acceptor.erl \
-	src/mochiweb_app.erl \
-	src/mochiweb_charref.erl \
-	src/mochiweb_cookies.erl \
-	src/mochiweb_cover.erl \
-	src/mochiweb_echo.erl \
-	src/mochiweb_headers.erl \
-	src/mochiweb_html.erl \
-	src/mochiweb_http.erl \
-	src/mochiweb_io.erl \
-	src/mochiweb_mime.erl \
-	src/mochiweb_multipart.erl \
-	src/mochiweb_request.erl \
-	src/mochiweb_request_tests.erl \
-	src/mochiweb_response.erl \
-	src/mochiweb_skel.erl \
-	src/mochiweb_socket.erl \
-	src/mochiweb_socket_server.erl \
-	src/mochiweb_sup.erl \
-	src/mochiweb_util.erl \
-	src/reloader.erl
-
-mochiwebebin_make_generated_file_list = \
-	ebin/mochifmt.beam \
-	ebin/mochifmt_records.beam \
-	ebin/mochifmt_std.beam \
-	ebin/mochiglobal.beam \
-	ebin/mochihex.beam \
-	ebin/mochijson.beam \
-	ebin/mochijson2.beam \
-	ebin/mochilists.beam \
-	ebin/mochilogfile2.beam \
-	ebin/mochinum.beam \
-	ebin/mochitemp.beam \
-	ebin/mochiutf8.beam \
-	ebin/mochiweb.app \
-	ebin/mochiweb.beam \
-	ebin/mochiweb_acceptor.beam \
-	ebin/mochiweb_app.beam \
-	ebin/mochiweb_charref.beam \
-	ebin/mochiweb_cookies.beam \
-	ebin/mochiweb_cover.beam \
-	ebin/mochiweb_echo.beam \
-	ebin/mochiweb_headers.beam \
-	ebin/mochiweb_html.beam \
-	ebin/mochiweb_http.beam \
-	ebin/mochiweb_io.beam \
-	ebin/mochiweb_mime.beam \
-	ebin/mochiweb_multipart.beam \
-	ebin/mochiweb_request.beam \
-	ebin/mochiweb_response.beam \
-	ebin/mochiweb_skel.beam \
-	ebin/mochiweb_socket.beam \
-	ebin/mochiweb_socket_server.beam \
-	ebin/mochiweb_sup.beam \
-	ebin/mochiweb_util.beam \
-	ebin/reloader.beam
-
-mochiwebebin_DATA = \
-    $(mochiwebebin_make_generated_file_list)
-
-EXTRA_DIST =  \
-    $(mochiweb_file_collection) \
-    src/internal.hrl
-
-CLEANFILES = \
-    $(mochiwebebin_make_generated_file_list)
-
-ebin/%.app: src/%.app.in
-	@mkdir -p ebin/
-	cp $< $@
-
-ebin/mochijson2.beam: src/mochijson2.erl
-	@mkdir -p ebin/
-	$(ERLC) -o ebin/ $(ERLC_FLAGS) $(MOCHIJSON_ERLC_FLAGS) $<
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mochiweb/src/mochiweb.app.in
----------------------------------------------------------------------
diff --git a/src/mochiweb/src/mochiweb.app.in b/src/mochiweb/src/mochiweb.app.in
deleted file mode 100644
index 6a4a314..0000000
--- a/src/mochiweb/src/mochiweb.app.in
+++ /dev/null
@@ -1,32 +0,0 @@
-{application, mochiweb,
- [{description, "MochiMedia Web Server"},
-  {vsn, "1.4.1"},
-  {modules, [
-        mochihex,
-        mochijson,
-        mochijson2,
-        mochinum,
-        mochiweb,
-        mochiweb_app,
-        mochiweb_charref,
-        mochiweb_cookies,
-        mochiweb_echo,
-        mochiweb_headers,
-        mochiweb_html,
-        mochiweb_http,
-        mochiweb_multipart,
-        mochiweb_request,
-        mochiweb_response,
-        mochiweb_skel,
-        mochiweb_socket_server,
-        mochiweb_sup,
-        mochiweb_util,
-        reloader,
-        mochifmt,
-        mochifmt_std,
-        mochifmt_records
-	    ]},
-  {registered, []},
-  {mod, {mochiweb_app, []}},
-  {env, []},
-  {applications, [kernel, stdlib]}]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/mochiweb/src/mochiweb.app.src
----------------------------------------------------------------------
diff --git a/src/mochiweb/src/mochiweb.app.src b/src/mochiweb/src/mochiweb.app.src
index 37a21fb..c240102 100644
--- a/src/mochiweb/src/mochiweb.app.src
+++ b/src/mochiweb/src/mochiweb.app.src
@@ -1,7 +1,6 @@
-%% This is generated from src/mochiweb.app.src
 {application, mochiweb,
  [{description, "MochiMedia Web Server"},
-  {vsn, "1.4.1"},
+  {vsn, git},
   {modules, []},
   {registered, []},
   {mod, {mochiweb_app, []}},

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/oauth/Makefile.am
----------------------------------------------------------------------
diff --git a/src/oauth/Makefile.am b/src/oauth/Makefile.am
deleted file mode 100644
index 1636d98..0000000
--- a/src/oauth/Makefile.am
+++ /dev/null
@@ -1,41 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-oauthebindir = $(localerlanglibdir)/oauth/ebin
-
-oauth_file_collection = \
-	src/oauth.app.in \
-    src/oauth.erl
-
-# Removed oauth_rsa_sha1.beam until we require R12B5 or
-# we add a ./configure option to enable it.
-
-oauthebin_make_generated_file_list = \
-	ebin/oauth.app \
-    ebin/oauth.beam
-
-oauthebin_DATA = \
-	$(oauthebin_make_generated_file_list)
-
-EXTRA_DIST = \
-	$(oauth_file_collection)
-
-CLEANFILES = \
-    $(oauthebin_make_generated_file_list)
-
-ebin/%.app: src/%.app.in
-	@mkdir -p ebin/
-	cp $< $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/oauth/src/oauth.app.in
----------------------------------------------------------------------
diff --git a/src/oauth/src/oauth.app.in b/src/oauth/src/oauth.app.in
deleted file mode 100644
index a8ec17c..0000000
--- a/src/oauth/src/oauth.app.in
+++ /dev/null
@@ -1,20 +0,0 @@
-{application, oauth, [
-  {description, "Erlang OAuth implementation"},
-  {vsn, "7d85d3ef"},
-  {modules, [
-    oauth,
-    oauth_hmac_sha1,
-    oauth_http,
-    oauth_plaintext,
-    oauth_rsa_sha1,
-    oauth_unix,
-    oauth_uri
-  ]},
-  {registered, []},
-  {applications, [
-    kernel,
-    stdlib,
-    crypto,
-    inets
-  ]}
-]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/oauth/src/oauth.app.src
----------------------------------------------------------------------
diff --git a/src/oauth/src/oauth.app.src b/src/oauth/src/oauth.app.src
new file mode 100644
index 0000000..a8ec17c
--- /dev/null
+++ b/src/oauth/src/oauth.app.src
@@ -0,0 +1,20 @@
+{application, oauth, [
+  {description, "Erlang OAuth implementation"},
+  {vsn, "7d85d3ef"},
+  {modules, [
+    oauth,
+    oauth_hmac_sha1,
+    oauth_http,
+    oauth_plaintext,
+    oauth_rsa_sha1,
+    oauth_unix,
+    oauth_uri
+  ]},
+  {registered, []},
+  {applications, [
+    kernel,
+    stdlib,
+    crypto,
+    inets
+  ]}
+]}.

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/rexi/.gitignore
----------------------------------------------------------------------
diff --git a/src/rexi/.gitignore b/src/rexi/.gitignore
deleted file mode 100644
index 4f2f040..0000000
--- a/src/rexi/.gitignore
+++ /dev/null
@@ -1,8 +0,0 @@
-# building
-ebin
-.eunit
-logs
-*.spec
-deps
-*.beam
-

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/rexi/Makefile.am
----------------------------------------------------------------------
diff --git a/src/rexi/Makefile.am b/src/rexi/Makefile.am
deleted file mode 100644
index e658627..0000000
--- a/src/rexi/Makefile.am
+++ /dev/null
@@ -1,48 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License.  You may obtain a copy
-## of the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-rexiebindir = $(localerlanglibdir)/rexi/ebin
-
-rexiebin_DATA = $(compiled_files)
-
-source_files = \
-	src/rexi.app.src \
-    src/rexi.erl \
-	src/rexi_app.erl \
-	src/rexi_gov_manager.erl \
-	src/rexi_governor.erl \
-	src/rexi_monitor.erl \
-	src/rexi_server.erl \
-	src/rexi_sup.erl \
-	src/rexi_utils.erl
-
-compiled_files = \
-	ebin/rexi.app \
-    ebin/rexi.beam \
-	ebin/rexi_app.beam \
-	ebin/rexi_gov_manager.beam \
-	ebin/rexi_governor.beam \
-	ebin/rexi_monitor.beam \
-	ebin/rexi_server.beam \
-	ebin/rexi_sup.beam \
-	ebin/rexi_utils.beam
-
-EXTRA_DIST = $(source_files)
-CLEANFILES = $(compiled_files)
-
-ebin/%.app: src/%.app.src
-	@mkdir -p ebin/
-	sed -e "s|%version%|@version@|g" < $< > $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -Wall -I$(top_srcdir)/src -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/rexi/src/rexi.app.src
----------------------------------------------------------------------
diff --git a/src/rexi/src/rexi.app.src b/src/rexi/src/rexi.app.src
index c9af9d0..0691edd 100644
--- a/src/rexi/src/rexi.app.src
+++ b/src/rexi/src/rexi.app.src
@@ -12,7 +12,7 @@
 
 {application, rexi, [
     {description, "Lightweight RPC server"},
-    {vsn, "%version%"},
+    {vsn, git},
     {modules, [
         rexi,
         rexi_app,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/snappy/Makefile.am
----------------------------------------------------------------------
diff --git a/src/snappy/Makefile.am b/src/snappy/Makefile.am
deleted file mode 100644
index baa4f68..0000000
--- a/src/snappy/Makefile.am
+++ /dev/null
@@ -1,40 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-SUBDIRS = c_src
-
-snappyebindir = $(localerlanglibdir)/snappy-1.0.5/ebin
-
-snappy_file_collection = \
-    src/snappy.app.in \
-    src/snappy.erl
-
-snappyebin_make_generated_file_list = \
-    ebin/snappy.app \
-    ebin/snappy.beam
-
-snappyebin_DATA = \
-	$(snappyebin_make_generated_file_list)
-
-EXTRA_DIST = \
-    $(snappy_file_collection)
-
-CLEANFILES = \
-    $(snappyebin_make_generated_file_list)
-
-ebin/%.app: src/%.app.in
-	@mkdir -p ebin/
-	cp $< $@
-
-ebin/%.beam: src/%.erl
-	@mkdir -p ebin/
-	$(ERLC) -o ebin/ $(ERLC_FLAGS) $<

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/snappy/c_src/Makefile.am
----------------------------------------------------------------------
diff --git a/src/snappy/c_src/Makefile.am b/src/snappy/c_src/Makefile.am
deleted file mode 100644
index 3a5d6cd..0000000
--- a/src/snappy/c_src/Makefile.am
+++ /dev/null
@@ -1,58 +0,0 @@
-## Licensed under the Apache License, Version 2.0 (the "License"); you may not
-## use this file except in compliance with the License. You may obtain a copy of
-## the License at
-##
-##   http://www.apache.org/licenses/LICENSE-2.0
-##
-## Unless required by applicable law or agreed to in writing, software
-## distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-## WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-## License for the specific language governing permissions and limitations under
-## the License.
-
-snappyprivdir = $(localerlanglibdir)/snappy-1.0.5/priv
-
-snappy_cxx_srcs = \
-	snappy_nif.cc \
-	google-snappy/snappy.cc \
-	google-snappy/snappy-sinksource.cc \
-	google-snappy/snappy-stubs-internal.cc
-
-snappy_cxx_hdrs = \
-	erl_nif_compat.h \
-	google-snappy/snappy.h \
-	google-snappy/snappy-internal.h \
-	google-snappy/snappy-sinksource.h \
-	google-snappy/snappy-stubs-internal.h \
-	google-snappy/snappy-stubs-public.h.in
-
-EXTRA_DIST = \
-    google-snappy/AUTHORS \
-    google-snappy/COPYING \
-	$(snappy_cxx_hdrs)
-
-CLEANFILES = \
-	../priv/snappy_nif.so
-
-if USE_OTP_NIFS
-snappypriv_LTLIBRARIES = snappy_nif.la
-snappy_nif_la_SOURCES = $(snappy_cxx_srcs)
-snappy_nif_la_CXXFLAGS = $(ERLANG_FLAGS)
-snappy_nif_la_LDFLAGS = -module -avoid-version
-
-if WINDOWS
-snappy_nif_la_LDFLAGS += -no-undefined
-snappy_nif_la_CXXFLAGS += -EHsc -Ox
-SNAPPY_SO_NAME = snappy_nif.dll
-else
-SNAPPY_SO_NAME = snappy_nif.so
-endif
-
-
-# This is purely to enable ./utils/run
-../priv/$(SNAPPY_SO_NAME): snappy_nif.la
-	@mkdir -p ../priv
-	cp .libs/$(SNAPPY_SO_NAME) $@
-
-all: ../priv/$(SNAPPY_SO_NAME)
-endif

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/snappy/src/snappy.app.in
----------------------------------------------------------------------
diff --git a/src/snappy/src/snappy.app.in b/src/snappy/src/snappy.app.in
deleted file mode 100644
index 25d37b5..0000000
--- a/src/snappy/src/snappy.app.in
+++ /dev/null
@@ -1,12 +0,0 @@
-{application, snappy,
- [
-  {description, "snappy compressor/decompressor Erlang NIF wrapper"},
-  {vsn, "1.0.5"},
-  {registered, []},
-  {applications, [
-                  kernel,
-                  stdlib
-                 ]},
-  {env, []},
-  {modules, [snappy]}
- ]}.
diff --git a/src/fabric/src/fabric_view_reduce.erl b/src/fabric/src/fabric_view_reduce.erl
index 54dcdf5..c922a7f 100644
--- a/src/fabric/src/fabric_view_reduce.erl
+++ b/src/fabric/src/fabric_view_reduce.erl
@@ -17,6 +17,7 @@
 -include_lib("fabric/include/fabric.hrl").
 -include_lib("mem3/include/mem3.hrl").
 -include_lib("couch/include/couch_db.hrl").
+-include_lib("couch_mrview/include/couch_mrview.hrl").
 
 go(DbName, GroupId, View, Args, Callback, Acc0) when is_binary(GroupId) ->
     {ok, DDoc} = fabric:open_doc(DbName, <<"_design/", GroupId/binary>>, []),
@@ -27,13 +28,13 @@ go(DbName, DDoc, VName, Args, Callback, Acc0) ->
     Lang = couch_view_group:get_language(Group),
     Views = couch_view_group:get_views(Group),
     {NthRed, View} = fabric_view:extract_view(nil, VName, Views, reduce),
-    {VName, RedSrc} = lists:nth(NthRed, View#view.reduce_funs),
+    {VName, RedSrc} = lists:nth(NthRed, View#mrview.reduce_funs),
     Workers = lists:map(fun(#shard{name=Name, node=N} = Shard) ->
         Ref = rexi:cast(N, {fabric_rpc, reduce_view, [Name,DDoc,VName,Args]}),
         Shard#shard{ref = Ref}
     end, fabric_view:get_shards(DbName, Args)),
     RexiMon = fabric_util:create_monitors(Workers),
     #view_query_args{limit = Limit, skip = Skip} = Args,
     OsProc = case os_proc_needed(RedSrc) of
         true -> couch_query_servers:get_os_process(Lang);
         _ -> nil
@@ -43,7 +44,7 @@ go(DbName, DDoc, VName, Args, Callback, Acc0) ->
         query_args = Args,
         callback = Callback,
         counters = fabric_dict:init(Workers, 0),
-        keys = Args#view_query_args.keys,
+        keys = Args#mrargs.keys,
         skip = Skip,
         limit = Limit,
         lang = Lang,

http://git-wip-us.apache.org/repos/asf/couchdb/blob/ba152cb2/src/ibrowse/Makefile.am
----------------------------------------------------------------------
@@ -27,13 +28,13 @@ go(DbName, DDoc, VName, Args, Callback, Acc0) ->
     end, fabric_view:get_shards(DbName, Args)),
     RexiMon = fabric_util:create_monitors(Workers),
-    #view_query_args{limit = Limit, skip = Skip} = Args,
+    #mrargs{limit = Limit, skip = Skip} = Args,
     OsProc = case os_proc_needed(RedSrc) of
         true -> couch_query_servers:get_os_process(Lang);